@@ -54,11 +54,11 @@ casts = [int, float, str2bool, str2list, str2args]
 cast = StringCaster(*casts)
 
 # cast by type
-cast_dict = dict([(i,i) for i in int, float])
+cast_dict = dict([(i,i) for i in (int, float)])
 cast_dict[bool] = str2bool
 cast_dict[tuple] = cast_dict[list] = str2list
 
 if __name__ == '__main__':
   import sys
   for arg in sys.argv[1:]:
-    print cast(arg)
+    print(cast(arg))
