@@ -12,7 +12,12 @@ __all__ = ['import_dotted_path', 'load']
 
 def import_dotted_path(module):
   path = module.split('.')
-  module = __import__(module)
+  try:
+    module = __import__(module)
+  except:
+    sys.stderr.write("pyloader: Error importing %s for dotted path %s\n" % (module, path))
+    raise
+
   for name in path[1:]:
     module = getattr(module, name)
   return module
@@ -40,7 +45,7 @@ def load(string):
       # module: dotted path
       return import_dotted_path(string)
   except:
-    print string
+    print (string)
     raise
 
   # TODO: entry points
@@ -48,4 +53,4 @@ def load(string):
 if __name__ == '__main__':
   import sys
   for i in sys.argv[1:]:
-    print load(i)
+    print(load(i))
