@@ -40,9 +40,10 @@ def parse(args):
         raise Exception
     return _args1, _args2, kw
 
+
 if __name__ == '__main__':
     import sys
     args, positional_args, kwargs = parse(sys.argv[1:])
-    print args
-    print positional_args
-    print kwargs
+    print (args)
+    print (positional_args)
+    print (kwargs)
